==> open-xchange-halo_7.10.0.orig.tar.bz2: open-xchange-halo-7.10.0/com.openexchange.halo.events/src/com/openexchange/halo/events/osgi/EventsHaloActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.halo.events.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.chronos.provider.composition.IDBasedCalendarAccessFactory;
import com.openexchange.halo.HaloContactDataSource;
import com.openexchange.halo.events.EventsContactHalo;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link EventsHaloActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class EventsHaloActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link EventsHaloActivator}.
     */
    public EventsHaloActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return EMPTY_CLASSES;
    }

    @Override
    protected void startBundle() throws Exception {
        /*
         * register events halo based on availability of id based calendar access factory
         */
        final BundleContext context = this.context;
        track(IDBasedCalendarAccessFactory.class, new ServiceTrackerCustomizer<IDBasedCalendarAccessFactory, IDBasedCalendarAccessFactory>() {

            private volatile ServiceRegistration<HaloContactDataSource> eventsHaloRegistration;

            @Override
            public IDBasedCalendarAccessFactory addingService(ServiceReference<IDBasedCalendarAccessFactory> serviceReference) {
                IDBasedCalendarAccessFactory calendarAccessFactory = context.getService(serviceReference);
                eventsHaloRegistration = context.registerService(HaloContactDataSource.class, new EventsContactHalo(calendarAccessFactory), null);
                return calendarAccessFactory;
            }

            @Override
            public void modifiedService(ServiceReference<IDBasedCalendarAccessFactory> serviceReference, IDBasedCalendarAccessFactory service) {
                // nothing to do
            }

            @Override
            public void removedService(ServiceReference<IDBasedCalendarAccessFactory> serviceReference, IDBasedCalendarAccessFactory service) {
                ServiceRegistration<HaloContactDataSource> eventsHaloRegistration = this.eventsHaloRegistration;
                if (null != eventsHaloRegistration) {
                    this.eventsHaloRegistration = null;
                    eventsHaloRegistration.unregister();
                }
                context.ungetService(serviceReference);
            }
        });
        openTrackers();
    }

}

==> open-xchange-halo_7.10.2.orig.tar.bz2: open-xchange-halo-7.10.2/com.openexchange.halo.events/src/com/openexchange/halo/events/osgi/EventsHaloActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.halo.events.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.chronos.provider.composition.IDBasedCalendarAccessFactory;
import com.openexchange.halo.HaloContactDataSource;
import com.openexchange.halo.events.EventsContactHalo;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link EventsHaloActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class EventsHaloActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link EventsHaloActivator}.
     */
    public EventsHaloActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return EMPTY_CLASSES;
    }

    @Override
    protected void startBundle() throws Exception {
        /*
         * register events halo based on availability of id based calendar access factory
         */
        final BundleContext context = this.context;
        track(IDBasedCalendarAccessFactory.class, new ServiceTrackerCustomizer<IDBasedCalendarAccessFactory, IDBasedCalendarAccessFactory>() {

            private ServiceRegistration<HaloContactDataSource> eventsHaloRegistration;

            @Override
            public synchronized IDBasedCalendarAccessFactory addingService(ServiceReference<IDBasedCalendarAccessFactory> serviceReference) {
                IDBasedCalendarAccessFactory calendarAccessFactory = context.getService(serviceReference);
                eventsHaloRegistration = context.registerService(HaloContactDataSource.class, new EventsContactHalo(calendarAccessFactory), null);
                return calendarAccessFactory;
            }

            @Override
            public void modifiedService(ServiceReference<IDBasedCalendarAccessFactory> serviceReference, IDBasedCalendarAccessFactory service) {
                // nothing to do
            }

            @Override
            public synchronized void removedService(ServiceReference<IDBasedCalendarAccessFactory> serviceReference, IDBasedCalendarAccessFactory service) {
                ServiceRegistration<HaloContactDataSource> eventsHaloRegistration = this.eventsHaloRegistration;
                if (null != eventsHaloRegistration) {
                    this.eventsHaloRegistration = null;
                    eventsHaloRegistration.unregister();
                }
                context.ungetService(serviceReference);
            }
        });
        openTrackers();
    }

}
